
% StatEns DOCUMENT STYLE -- version 1.0
% for Latex version 2.09

% This style file is an adaptation of the original Latex article.sty

\typeout{Document Style `StatEns', <version 1.0>}

%\RequirePackage[latin1]{inputenc}
\RequirePackage[frenchb,english]{babel}
\RequirePackage{fancyhdr}
\RequirePackage{ifthen}

\newboolean{@@french}

\LoadClass[12pt,twoside,a4paper]{article}

\setlength{\textwidth}{16cm}
%\setlength{\textheight}{23.7cm}
\setlength{\textheight}{23.4cm}

%%% Margins for centering the text on the page

\setlength{\oddsidemargin}{0cm}
\setlength{\evensidemargin}{0cm}
% Vertically: (1pt = 0.351mm)
% A4 paper height is 29.7cm = 845pt
\setlength{\topmargin}{-1cm}
\setlength{\headheight}{14.49998pt}
\setlength{\headsep}{1cm}
\setlength{\footskip}{1.2cm}

\setlength{\parskip}{6pt}
\setlength{\parindent}{0.6cm}

\newcommand{\bi}{\itshape \bfseries}

%%% Language switching

% Commands \Fr and \Eng for switching to French and English
% They use the Babel's \selectlanguage
% and redefine language specific actions
% of StatEns's special commands

\newcommand\Fr
		{\selectlanguage{frenchb}\lccode`\'=`\'%
     \renewcommand{\figurename}{\scshape{Figure}}%
     \renewcommand{\tablename}{\scshape{Tableau}}%
     \renewcommand{\bibname}{R\'ef\'erences}%    
     \setboolean{@@french}{true}%
    }
\newcommand\Eng
	  {\selectlanguage{english}\lccode`\'=0%
     \renewcommand{\figurename}{\scshape{Figure}}%
     \renewcommand{\tablename}{\scshape{Table}}%
     \renewcommand{\bibname}{References}%    
     \setboolean{@@french}{false}
    }

%%% (Re)defining some commands and environments

%% Title of the article

\newcommand{\doctitle}[1]
	{
	\begin{center}
	{\Large \bf #1 \\[1ex]}
	\end{center}
	}

%% Firstnames and names of the author(s)

\newcommand{\authors}[1]
	{
	\begin{center}
	{\large #1 \\[1ex]}
	\end{center}	
	\vskip 24pt
	}

%% Title/Titre, Rsum and Abstract

\newcommand{\etitle}[1]
	{
	\begin{minipage}{140mm}
	\footnotesize 
	\begin{center} 
	{\bf TITLE}
	\end{center}
	\vspace{-10pt} #1
	\normalsize
	\end{minipage}\bigskip
	}
	
\newcommand{\ftitle}[1]
	{
	\begin{minipage}{140mm}
	\footnotesize
	\begin{center} 
	{\bf TITRE}
	\end{center}
	\vspace{-6pt} #1
	\normalsize
	\end{minipage}\bigskip
	}
	
\newcommand{\resume}[2]
	{
	\begin{minipage}{140mm}
	\footnotesize
	\begin{center} 
	{\bf R\'ESUM\'E}
	\end{center}
	\vspace{-6pt} #1 
	\par {\bi Mots-cl\'es~:} {\it #2} 
	\normalsize
	\end{minipage}\bigskip
	}	
	
\newcommand{\summary}[2]
	{
	\begin{minipage}{140mm}
	\footnotesize
	\begin{center} 
	{\bf ABSTRACT}
	\end{center}
	\vspace{-6pt} #1
	\par {\bi Keywords~:} {\it #2} 
	\normalsize
	\end{minipage}\bigskip
	}	
	
%% Section of paragraphe type

\newcommand{\paragr}[2]
	{
	\vspace{6pt}\noindent {\bf #1}{~---~#2} 
	}

%% Captions for figures and tables

\newcommand*{\caphsep}{\normalfont\hskip .6ex\textendash\hskip .3ex}

\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{{\normalsize {#1\caphsep} {\normalfont\itshape #2}}}%
  \ifdim \wd\@tempboxa >\hsize
    {\normalsize {#1\caphsep}  
    {\normalfont\itshape #2}}
    \par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}
  
%% Guillemets franais (\gl{}texte\gr{})

\def\gl{\guillemotleft\kern .25ex\ignorespaces}
\def\gr{\kern .25ex\guillemotright}

%% Command \http{} 

\newcommand\http[1]
		{%
    \ifthenelse{\boolean{@@french}}%
    {\noextrasfrench{#1}\extrasfrench}%
    {#1}%
    }
 
%% Bibliography

\renewenvironment{thebibliography}[1]
     {\section*{\bibname}
      \@mkboth{\bibname}{\bibname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}

%% Handling headers and footers

%\setcounter{page}{1}
\newcommand{\vol}{x} %numro du volume
\newcommand{\num}{z} %numro du fascicule
\newcommand{\annee}{2009} %anne de publication
\newcommand{\refrevue}
	{
	 {\it Statistique et Enseignement}, {\bf \vol}(\num), pp-pp, \http{http://www.statistique-et-enseignement.fr}\\
	 \copyright ~Soci\'et\'e Fran\c{c}aise de Statistique (SFdS), Mois/Month \annee	
	}
	%{
	% {\it Statistique et Enseignement}, {\bf \vol}(\num), \pageref{page|first}-\pageref{page|last}, \http{http://www.statistique-et-enseignement.fr}\\
	% \copyright ~Soci\'et\'e Fran\c{c}aise de Statistique (SFdS), Mois/Month \annee	
	%}

% First page of the article
\fancypagestyle{firstpage}{%
	\fancyhead{} \fancyfoot{}                            
	\cfoot{\footnotesize \refrevue}}
	
% Other pages of the article
\pagestyle{fancy}

\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}
\fancyhead{} \fancyfoot{}
\newcommand*{\shorttitle}[1]{\fancyhead[CE]{\footnotesize {\it #1}}}
\newcommand*{\shortname}[1]{\fancyhead[CO]{\footnotesize {\it #1}}}
\fancyhead[LE]{\thepage} \fancyhead[RO]{\thepage}
\cfoot{\footnotesize \refrevue} 





 
     